---
title: <span class="badge builder"></span> ExprTypeClassicConditionsConditionsOperator
---
# <span class="badge builder"></span> ExprTypeClassicConditionsConditionsOperator

## Constructor

```python
ExprTypeClassicConditionsConditionsOperator()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> expr.ExprTypeClassicConditionsConditionsOperator
```

### <span class="badge object-method"></span> type_val

```python
def type_val(type_val: typing.Literal["and", "or", "logic-or"]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ExprTypeClassicConditionsConditionsOperator](./object-ExprTypeClassicConditionsConditionsOperator.md)
